{% load i18n %}
<h3>{% blocktrans with filter_title=title %} By {{ filter_title }} {% endblocktrans %}</h3>
<ul{% if spec.ajax_attrs %} class="ajax"{% endif %}{% if spec.ajax_attrs %}{{ spec.ajax_attrs }}{% endif %}>
    {% for choice in choices %}
        <li{% if choice.selected %} class="selected"{% endif %}>
        <a href="{{ choice.query_string|iriencode }}" title="{{ choice.display }}">{{ choice.display }}</a></li>
    {% endfor %}
</ul>
