{% load i18n %}


{% if module.error %}
    <ul>
        <li>
            {{ module.error }}
        </li>
    </ul>
{% elif module.children %}
    <table class="table">
        <thead>
            <tr>
                <th>{% trans "Date" %}</th>
                <th>{% trans "users" as label %}{{ label|capfirst }}</th>
                <th>{% trans "sessions" as label %}{{ label|capfirst }}</th>
                <th>{% trans "views" as label %}{{ label|capfirst }}</th>
            </tr>
        </thead>
        <tbody>
            {% for data in module.children %}
                <tr>
                    <th>{{ data.0 }}</th>
                    <td width="1" align="center">{{ data.1.ga_users }}</td>
                    <td width="1" align="center">{{ data.1.ga_sessions }}</td>
                    <td width="1" align="center">{{ data.1.ga_pageviews }}</td>
                </tr>
            {% endfor %}
        </tbody>
    </table>
{% else %}
    <ul>
        <li>
            {% trans "Nothing to show" %}
        </li>
    </ul>
{% endif %}

